petl - Extract, Transform and Load (Tables of Data)
===================================================

``petl`` is a general purpose Python package for extracting, transforming and
loading tables of data.

- Docs: http://petl.readthedocs.org/
- Source: https://github.com/petl-developers/petl
- Download: http://pypi.python.org/pypi/petl
- Mailing list: http://groups.google.com/group/python-etl

See also `petlx <https://github.com/alimanfoo/petlx>`_, a library of
extension modules for ``petl``.

.. image:: https://travis-ci.org/petl-developers/petl.svg?branch=master
    :target: https://travis-ci.org/petl-developers/petl
    :alt: continuous integration build status

.. image:: https://ci.appveyor.com/api/projects/status/nttbwesq6p4bd5qr?svg=true
    :target: https://ci.appveyor.com/project/petl-developers/petl

.. image:: https://readthedocs.org/projects/petl/badge/?version=stable
    :target: http://petl.readthedocs.io/en/stable/?badge=stable

.. image:: https://coveralls.io/repos/github/petl-developers/petl/badge.svg?branch=master
    :target: https://coveralls.io/github/petl-developers/petl?branch=master

.. image:: https://zenodo.org/badge/2233194.svg
   :target: https://zenodo.org/badge/latestdoi/2233194
